//// [file1.ts]
declare const enum E { X = 1}
export var y = E.X;


//// [file1.js]
export var y = E.X;
